@@ -31,10 +31,15 @@
 #include <locale.h>
 #include <vector>
 #include <map>
+#include <set>
 #include <string>
 #include <libintl.h>
+#include <math.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
+#include <goffice/utils/go-math.h>
+
+static set<string>units;
 
 static void ReadValue (char const *source, GcuValue &value)
 {
@@ -87,6 +92,7 @@ EltTable::EltTable()
 	Langs["fr"] = _("French");
 	Langs["it"] = _("Italian");
 	Langs["pl"] = _("Polish");
+	Langs["ru"] = _("Russian");
 	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/elements.xml")))
 	{
 		g_error (_("Can't find and read elements.xml"));
@@ -506,6 +512,7 @@ void Element::LoadElectronicProps ()
 	xmlDocPtr xml;
 	char *old_num_locale, *buf, *num, *dot, *end;
 	unsigned char Z;
+	unsigned i;
 	static bool loaded = false;
 	if (loaded)
 		return;
@@ -553,7 +560,6 @@ void Element::LoadElectronicProps ()
 					buf = (char*) xmlNodeGetContent (child);
 					char *cur = buf;
 					bool nonvoid = false;
-					int i;
 					if (buf[0] == '[') {
 						Elt->ElecConfig.append (buf, 4);
 						cur += 4;
@@ -577,7 +583,75 @@ void Element::LoadElectronicProps ()
 					Elt->ElecConfig.append (" ");
 					xmlFree (buf);
 				} else if (!strcmp ((const char*) child->name, "ei")) {
+					unsigned rank;
+					buf = (char*) xmlGetProp (child, (xmlChar*) "rank");
+					if (buf) {
+						rank = strtol (buf, NULL, 10);
+						xmlFree (buf);
+					} else
+						rank = 1;
+					if ((i = Elt->m_ei.size ()) < rank) {
+						Elt->m_ei.resize (rank);
+						for (; i < rank; i++)
+							Elt->m_ei[i].value = go_nan;
+					}
+					rank--;
+					buf = (char*) xmlGetProp (child, (xmlChar*) "value");
+					if (buf) {
+						ReadValue (buf, (GcuValue&)Elt->m_ei[rank]) ;
+						xmlFree (buf);
+					} else {
+						//no need to read the unit
+						Elt->m_ei[rank].value = go_nan;
+						break;
+					}
+					buf = (char*) xmlGetProp (child, (xmlChar*) "unit");
+					if (buf) {
+						string str(buf);
+						set<string>::iterator it = units.find (str);
+						if (it == units.end ()) {
+							units.insert (str);
+							it = units.find (str);
+						}
+						Elt->m_ei[rank].unit = (*it).c_str ();
+						xmlFree (buf);
+					} else
+						Elt->m_ei[rank].unit = "MJ.mol<sup>-1</sup>";
 				} else if (!strcmp ((const char*) child->name, "ae")) {
+					unsigned rank;
+					buf = (char*) xmlGetProp (child, (xmlChar*) "rank");
+					if (buf) {
+						rank = strtol (buf, NULL, 10);
+						xmlFree (buf);
+					} else
+						rank = 1;
+					if ((i = Elt->m_ae.size ()) < rank) {
+						Elt->m_ae.resize (rank);
+						for (; i < rank; i++)
+							Elt->m_ae[i].value = go_nan;
+					}
+					rank--;
+					buf = (char*) xmlGetProp (child, (xmlChar*) "value");
+					if (buf) {
+						ReadValue (buf, (GcuValue&)Elt->m_ae[rank]) ;
+						xmlFree (buf);
+					} else {
+						//no need to read the unit
+						Elt->m_ae[rank].value = go_nan;
+						break;
+					}
+					buf = (char*) xmlGetProp (child, (xmlChar*) "unit");
+					if (buf) {
+						string str(buf);
+						set<string>::iterator it = units.find (str);
+						if (it == units.end ()) {
+							units.insert (str);
+							it = units.find (str);
+						}
+						Elt->m_ae[rank].unit = (*it).c_str ();
+						xmlFree (buf);
+					} else
+						Elt->m_ae[rank].unit = "kJ.mol<sup>-1</sup>";
 				} else
 					g_error ("Invalid property node");
 				child = child->next;
@@ -728,12 +802,12 @@ IsotopicPattern *Element::GetIsotopicPattern (unsigned natoms)
 	return result;
 }
 
-GcuDimensionalValue const *Element::GetIonizationEnergy (int rank)
+GcuDimensionalValue const *Element::GetIonizationEnergy (unsigned rank)
 {
-	return NULL;
+	return (rank <= m_ei.size ())? &m_ei[rank - 1]: NULL;
 }
 
-GcuDimensionalValue const *Element::GetElectronAffinity (int rank)
+GcuDimensionalValue const *Element::GetElectronAffinity (unsigned rank)
 {
-	return NULL;
+	return (rank <= m_ae.size ())? &m_ae[rank - 1]: NULL;
 }
