@@ -8,40 +8,42 @@
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 #ifndef GCU_ELEMENT_H
 #define GCU_ELEMENT_H
 
 #include <glib.h>
+#include <map>
 #include <string>
 #include <vector>
 #include "chemistry.h"
+#include "isotope.h"
 
 using namespace std;
 
-class EltTable;
-
 /*!\namespace gcu
 The namespace used for all C++ classes provided by the Gnome Chemistry Utils.
 */
 namespace gcu
 {
 
+class EltTable;
+
 /*!\class Element gcu/element.h
 	Represents a chemical element.
 	This class has no public constructor or destructor. The instances are created by the framework
@@ -216,7 +218,18 @@ public:
 	@return the atomic mass of the element.
 	*/
 	double GetWeight (int& prec) {prec = m_WeightPrec; return m_Weight;}
-	
+	/*!
+	@param natoms: atoms count.
+
+	@return the isotopic pattern correponding to a fragment containing n atoms of the
+	element.
+	*/
+	IsotopicPattern *GetIsotopicPattern (unsigned natoms);
+	string const& GetElectronicConfiguration () {return ElecConfig;}
+	map<string, string> const& GetNames () {return names;}
+	GcuDimensionalValue const *GetIonizationEnergy (unsigned rank = 1);
+	GcuDimensionalValue const *GetElectronAffinity (unsigned rank = 1);
+
 private:
 	unsigned char m_Z, m_nve, m_tve, m_maxve;
 	char m_Symbol[4];
@@ -229,6 +242,12 @@ private:
 	string name;
 	vector<GcuAtomicRadius*> m_radii;
 	vector<GcuElectronegativity*> m_en;
+	vector<Isotope*> m_isotopes;
+	vector<IsotopicPattern*> m_patterns;
+	vector<GcuDimensionalValue> m_ei;
+	vector<GcuDimensionalValue> m_ae;
+	map<string, string> names;
+	string ElecConfig;
 };
 
 } // namespace gcu
