@@ -1,5 +1,6 @@
 #include "config.h"
-#include <chem3d/gtkchem3dviewer.h>
+#include <gcu/chemistry.h>
+#include <gcu/gtkchem3dviewer.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -18,6 +19,8 @@ int main(int argc, char *argv[])
 		printf ("Could not initialize GnomeVFS\n");
 		return 1;
 	}
+	
+	gcu_element_load_databases ("radii", NULL);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(window), "GtkChem3dViewer test");
